/*
 * File:   O-BUZZER
 * Author: Bart Huyskens - www.e2cre8.be  04/2016
 * HARDWARE: BRAINBOX FUN - PIC18F445 + Bootloader running at 48Mhz
 * 
* This program alternatingly makes 4 20mA output pins high
 * with 100msec delays
 * 4 ouput pins connected to B7 - B6 - A5 - A4
 */
// PIC18F4455 Configuration Bit Settings - 
// all config settings are made in the bootloader

#include <xc.h>   // general XC8 library
#define _XTAL_FREQ 48000000  // Brainbox Fun running at 48Mhz

#define OUTA4 PORTAbits.RA4    // using a define to give pin a better name
#define OUTA5 PORTAbits.RA5    // using a define to give pin a better name
#define OUTB6 PORTBbits.RB6    // using a define to give pin a better name
#define OUTB7 PORTBbits.RB7    // using a define to give pin a better name

    // The delay routine of the XC8 compiler is limited. 
    // __delay_ms(100); would be too large 
    // Solution: this function that repeats the 10msec delay 10 times
    void delay_10ms(unsigned char n) 
     { 
         while (n-- != 0) { 
             __delay_ms(10); 
         } 
     }

void main(void) // main program
{  
    TRISAbits.RA4 = 0; // make pin output pin
    TRISAbits.RA5 = 0; // make pin output pin
    TRISBbits.RB6 = 0; // make pin output pin
    TRISBbits.RB7 = 0; // make pin output pin
 
    while(1)
        { // never ending loop
        
            OUTA4 = 1; OUTA5 = 0; OUTB6 = 0; OUTB7 = 0;
            delay_10ms(10); // generates a 100msec delay
            OUTA4 = 0; OUTA5 = 1; OUTB6 = 0; OUTB7 = 0;
            delay_10ms(10); // generates a 100msec delay
            OUTA4 = 0; OUTA5 = 0; OUTB6 = 1; OUTB7 = 0;
            delay_10ms(10); // generates a 100msec delay
            OUTA4 = 0; OUTA5 = 0; OUTB6 = 0; OUTB7 = 1;
            delay_10ms(10); // generates a 100msec delay
        }
}
